@@ -3,7 +3,8 @@
 # objects using coda::as.mcmc(). This requires R2jags:::as.mcmc.rjags() to 
 # work properly, so load the package before running any test files. 
 
-library(R2jags)  
+library(R2jags)
+library(runjags)
 
 # Maintainer note 11/2021: Need to check that the above is still true in mcmcAveProb().
 # At first glance, coda does not seem to depend on R2jags, and check with 
@@ -13,4 +14,7 @@ library(R2jags)
 # to include r2jags namespace when needed and get rid of this file
 # for greater clarity in future
 
+## Note 5/2022: Yup still true. R2jags seems to be needed for everything using
+## coda::as.mcmc(), so moving to a depends.
+
 
